##  Overview
Microsoft Exchange Online is a cloud-based messaging platform, available as part of Microsoft 365. Mailboxes within Exchange Online let you send emails to specific recipients.
You can set up an Exchange Online mailbox to deliver SAP LeanIX notifications instead of using the default SAP LeanIX email service. This setup allows for greater control over email processes, improved security measures, and a more streamlined communication workflow.
**Note**
If you set up an Exchange Online mailbox for email delivery, this configuration applies at the account level across all of your organization’s workspaces.
